#[repr(C)]pub struct CompletionContextClass(/* private fields */);Trait Implementations
Sourceimpl Debug for CompletionContextClass
impl Debug for CompletionContextClass
Sourceimpl Deref for CompletionContextClass
impl Deref for CompletionContextClass
Sourcetype Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
Sourceimpl DerefMut for CompletionContextClass
impl DerefMut for CompletionContextClass
Sourceimpl IsClassFor for CompletionContextClass
impl IsClassFor for CompletionContextClass
Sourcetype Instance = CompletionContext
type Instance = CompletionContext
Corresponding Rust instance type for this class.
Sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
Sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
Sourcefn downcast_ref<U>(&self) -> Option<&U>
fn downcast_ref<U>(&self) -> Option<&U>
Casts this class to a reference to a child type’s class or
fails if this class is not implementing the child class.
Sourcefn downcast_ref_mut<U>(&mut self) -> Option<&mut U>
fn downcast_ref_mut<U>(&mut self) -> Option<&mut U>
Casts this class to a mutable reference to a child type’s class or
fails if this class is not implementing the child class.
impl Send for CompletionContextClass
impl Sync for CompletionContextClass