#[repr(C)]pub struct GutterClass(/* private fields */);Trait Implementations
Sourceimpl Debug for GutterClass
impl Debug for GutterClass
Sourceimpl Deref for GutterClass
impl Deref for GutterClass
Sourcetype Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
Sourceimpl DerefMut for GutterClass
impl DerefMut for GutterClass
Sourceimpl IsClassFor for GutterClass
impl IsClassFor for GutterClass
Sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
Sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
Sourcefn downcast_ref<U>(&self) -> Option<&U>
fn downcast_ref<U>(&self) -> Option<&U>
Casts this class to a reference to a child type’s class or
fails if this class is not implementing the child class.
Sourcefn downcast_ref_mut<U>(&mut self) -> Option<&mut U>
fn downcast_ref_mut<U>(&mut self) -> Option<&mut U>
Casts this class to a mutable reference to a child type’s class or
fails if this class is not implementing the child class.
impl Send for GutterClass
impl Sync for GutterClass