#[repr(C)]pub struct ViewClass(/* private fields */);Trait Implementations
Sourceimpl Deref for ViewClass
impl Deref for ViewClass
Sourcetype Target = <TextView as ObjectType>::RustClassType
type Target = <TextView as ObjectType>::RustClassType
The resulting type after dereferencing.
Sourceimpl IsClassFor for ViewClass
impl IsClassFor for ViewClass
Sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
Sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
Sourcefn downcast_ref<U>(&self) -> Option<&U>
fn downcast_ref<U>(&self) -> Option<&U>
Casts this class to a reference to a child type’s class or
fails if this class is not implementing the child class.
Sourcefn downcast_ref_mut<U>(&mut self) -> Option<&mut U>
fn downcast_ref_mut<U>(&mut self) -> Option<&mut U>
Casts this class to a mutable reference to a child type’s class or
fails if this class is not implementing the child class.
impl Send for ViewClass
impl Sync for ViewClass